@@ -159,6 +159,3 @@ class AtomicGraphGenerator:
         p.modifiers.clear()
         return area, volume, count, dump_path
 
-if __name__ == "__main__":
-    gen = AtomicGraphGenerator()
-    gen.run()
